==> apache-asterixdb-0.9.2-source-release.zip: apache-asterixdb-0.9.2/asterix-common/src/main/java/org/apache/asterix/common/transactions/ITransactionSubsystem.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.common.transactions;

import org.apache.asterix.common.config.TransactionProperties;

/**
 * A transaction subsystem is responsible of maintaining Atomicity, Consistency, Isolation, and Durability
 * on a record level.
 */
public interface ITransactionSubsystem {

    ILogManager getLogManager();

    ILockManager getLockManager();

    ITransactionManager getTransactionManager();

    IRecoveryManager getRecoveryManager();

    IAppRuntimeContextProvider getAsterixAppRuntimeContextProvider();

    String getId();

    ICheckpointManager getCheckpointManager();

    TransactionProperties getTransactionProperties();

    void incrementEntityCommitCount();
}

==> apache-asterixdb-0.9.8-source-release.zip: apache-asterixdb-0.9.8/asterix-common/src/main/java/org/apache/asterix/common/transactions/ITransactionSubsystem.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.common.transactions;

import org.apache.asterix.common.api.INcApplicationContext;
import org.apache.asterix.common.config.TransactionProperties;

/**
 * A transaction subsystem is responsible of maintaining Atomicity, Consistency, Isolation, and Durability
 * on a record level.
 */
public interface ITransactionSubsystem {

    ILogManager getLogManager();

    ILockManager getLockManager();

    ITransactionManager getTransactionManager();

    IRecoveryManager getRecoveryManager();

    INcApplicationContext getApplicationContext();

    String getId();

    ICheckpointManager getCheckpointManager();

    TransactionProperties getTransactionProperties();

    void incrementEntityCommitCount();
}
